==> haskell-vector-0.12.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector
version: 0.12.0.1
id: vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
key: vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
license: BSD-3-Clause
copyright: (c) Roman Leshchinskiy 2008-2012
maintainer: Haskell Libraries Team <libraries@haskell.org>
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: https://github.com/haskell/vector
synopsis: Efficient Arrays
description:
    .
    An efficient implementation of Int-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>
category: Data, Data Structures
abi: b89d01d6ac629b85b27ded25ccb6f6d5
exposed: True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Unboxed Data.Vector.Unboxed.Base
    Data.Vector.Unboxed.Mutable
import-dirs: /usr/lib/ghc-8.6.2/site-local/vector-0.12.0.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/vector-0.12.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/vector-0.12.0.1
hs-libraries: HSvector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
include-dirs: /usr/lib/ghc-8.6.2/site-local/vector-0.12.0.1/include
depends:
    base-4.12.0.0 deepseq-1.4.4.0 ghc-prim-0.5.3
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
haddock-interfaces: /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html: /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-0.12.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector
version: 0.12.0.2
id: vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
key: vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
license: BSD-3-Clause
copyright: (c) Roman Leshchinskiy 2008-2012
maintainer: Haskell Libraries Team <libraries@haskell.org>
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage: https://github.com/haskell/vector
synopsis: Efficient Arrays
description:
    .
    An efficient implementation of Int-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>
category: Data, Data Structures
abi: 73b7d0c5eb836a148e91991180cfc63a
exposed: True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Unboxed Data.Vector.Unboxed.Base
    Data.Vector.Unboxed.Mutable
import-dirs: /usr/lib/ghc-8.6.3/site-local/vector-0.12.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/vector-0.12.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/vector-0.12.0.2
hs-libraries: HSvector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
include-dirs: /usr/lib/ghc-8.6.3/site-local/vector-0.12.0.2/include
depends:
    base-4.12.0.0 deepseq-1.4.4.0 ghc-prim-0.5.3
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
haddock-interfaces: /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html: /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
